<?php
/*********************************************************************************/
/*     Copyright (C) 2004-2005 Jean-Sbastien H. ( ED ) ( Livebox-script.com )   */
/*                                                                               */
/*     This file is part of Uptime Script                                        */
/*                                                                               */
/*     Uptime Script is free software; you can redistribute it and/or modify     */
/*     it under the terms of the GNU General Public License as published by      */
/*     the Free Software Foundation; either version 2 of the License, or         */
/*     (at your option) any later version.                                       */
/*                                                                               */ 
/*     Uptime Script is distributed in the hope that it will be useful,          */
/*     but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */ 
/*     GNU General Public License for more details.                              */
/*                                                                               */
/*     You should have received a copy of the GNU General Public License         */ 
/*     along with Uptime Script; if not, write to the Free Software              */
/*     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA */
/*********************************************************************************/
/*                                                                               */
/*         Fichier AbstractLivebox.php                                       */
/*         Cr le 26 aout 2006                                                  */
/*                                                              				 */
/*         Derniere modification: 30 aout 2006   - v4.0.0.alpha-rev9             */
/*                                                                               */
/*********************************************************************************/

abstract class AbstractLivebox {

	// Les attributs
	
	protected $livebox;
	protected $data;

	public function __construct($ip,$user,$passwd) {
	    if($this->checkConnection($ip)) {
			$this->data = $this->getData($ip,$user,$passwd);	
		}
		else exit("Pas de rseau"); // sortie une peu violente: a traiter plus finement.
	}
	
	/*
	*	Mise en mmoire des pages Livebox
	*	@param{ IP } - Adresse IP de la livebox - default: 192.168.1.1
	*	@param{ String } - Nom administrateur de la livebox - default: admin
	*	@param{ String } - Adresse IP de la livebox - default: admin
	*	@return { string }
	*/
	abstract protected function getData($ip="192.168.1.1",$user="admin",$passwd="admin");
		 		  
	// Verifie que l'on a accs  la livebox	
    protected function checkConnection($ip) {
		$fp = @fsockopen($ip,80,$errno,$errdescr,3);
        if($fp) return true; 
			return false; 
	} // fin CheckConnection()  	
         
    // Les mthodes get: permettent l'accs aux attributs depuis l'exterieur!
	
	public function getLivebox() {
		return $this->livebox;
	}
	    
	abstract public function getFirmware();
	
	abstract public function getUptime();
	
	abstract public function getIP();
	
	abstract public function getSNR();
	
	abstract public function getAttenuation();
	
	abstract public function getSNR_UP();
	
	abstract public function getAttenuation_UP();
	
	abstract public function getDownload();
	
	abstract public function getAttainableDownStream();
	
	abstract public function getUpload();
	
	abstract public function getAttainableUpStream();
	
	abstract public function getVoIP();

	abstract public function getCRC();
	
	abstract public function getCRC_UNCORR();
	
	abstract public function getCRC_UP();
	
	abstract public function getCRC_UNCORR_UP();

	/*
	*	Mesure du dbit sur une interface.
	*	@param { string } - nom de l'interface
	*	@return Array(  RX , TX )
	*/
	abstract public function getStreamOnInterface($interface);
	
	public function explainUptime($uptime) {
        $heure = floor($uptime / 60);
        $jour = floor($uptime / (60*24));
        $heure = $heure - $jour*24;
        $minute = $uptime - ($jour*24*60 + $heure * 60);
        return $jour." j - ".$heure." h - ".$minute." min";    
	} // fin GetUptime         	 
	
	// Exporte les informations au format XML
	// => preloader de l'index
	public function parseXML() {
		$result = "<liveboxInfos>\n";
		$result .= "<livebox>".$this->getLivebox()."</livebox>\n";
		$result .= "<firmware>".$this->getFirmware()."</firmware>\n";
		$result .= "<uptime>".$this->getUptime()."</uptime>\n";
		//$result .= "<ip>".$this->getIP()."</ip>\n";
		$result .= "<snr>".$this->getSNR()."</snr>\n";
		$result .= "<attenuation>".$this->getAttenuation()."</attenuation>\n";
		$result .= "<download>".$this->getDownload()."</download>\n";
		$result .= "<upload>".$this->getUpload()."</upload>\n";
		$result .= "<voip>".$this->getVoIP()."</voip>\n";
		$result .= "</liveboxInfos>\n";
		return $result;		 
	}

	public function parseHTML() {
		$result = "<ul>";
   		$result .= "<li class='infoLive'>";
		$result .= "   <ul>";
		$result .= "        <li><b>Livebox</b>: ".$this->getLivebox()."</li>";
		$result .= "        <li><b>Firmware</b>: ".$this->getFirmware()."</li>";
		$result .= "        <li><b>".I10N_SYNCHRO_FOR."</b>: ".$this->explainUptime($this->getUptime())."</li>	";
		$result .= "";
		$result .= "   </ul>";
		$result .= "</li>";
		$result .= "<li class='infoLive'>";
		$result .= "<ul>";
		$result .= "   <li><b>".I10N_SNR."</b>: ".$this->getSNR()." db</li>";	
		$result .= "       <li><b>".I10N_AFF."</b>: ".$this->getAttenuation()." db</li>	";
		$result .= "       <li><b>".I10N_PALIER_FT."</b>: ".$this->getDownload()." ko/s - ".$this->getUpload()." ko/s</li>	";		  
		$result .= "   </ul>";
		$result .= "</li>";
		$result .= "</ul>	";
		return $result;
	}

	protected function strAnalyser($str,$pattern) {
		$tmp = preg_match($pattern, $str,$matches);
		if($tmp != 0) return $matches[1];
        else return false;
    }
		   
    public function __toString() {
		$toDisplay = "<h3>Rapport d'analyse Livebox ".$this->getLivebox()." ( ".$this->getFirmware()." )</h3>\n";
		
		 $toDisplay .= "<h4>Infos Diverses:</h4>\n";
        $toDisplay .= "<ul>\n";

        $get = $this->GetUptime();
        $toDisplay .= "<li><b>Uptime</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";
		
		// IP
		$get = $this->GetIP();
        $toDisplay .= "<li><b>IP</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";
        
		// VoIP
        $get = $this->GetVoIP();
        $toDisplay .= "<li><b>VoIP</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";
		
		$toDisplay .= "</ul>\n";
		
		// Voie montante
		$toDisplay .= "<h4>Voie Montante:</h4>";
		$toDisplay .= "<ul>";
        $get = $this->GetUpload();
        $toDisplay .= "<li><b>UpStream</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";

        $get = $this->GetAttainableUpStream();
        $toDisplay .= "<li><b>Attainable UpStream</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";

        $get = $this->GetSNR_UP();
        $toDisplay .= "<li><b>SNR</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";
		
        $get = $this->GetAttenuation_UP();
        $toDisplay .= "<li><b>Attenuation</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";
		
        $get = $this->GetCRC_UP();
        $toDisplay .= "<li><b>CRC</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";

        $get = $this->GetCRC_UNCORR_UP();
        $toDisplay .= "<li><b>CRC UNCORR</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";
		$toDisplay .= "</ul>\n";
		
		// Voie descendante
		$toDisplay .= "<h4>Voie descendante:</h4>\n";
		$toDisplay .= "<ul>\n";
        $get = $this->GetDownload();
        $toDisplay .= "<li><b>DownStream</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";

        $get = $this->GetAttainableDownStream();
        $toDisplay .= "<li><b>Attainable DownStream</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";
		
		$get = $this->GetSNR();
        $toDisplay .= "<li><b>SNR</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";
		
        $get = $this->GetAttenuation();
        $toDisplay .= "<li><b>Attenuation</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";
		
        $get = $this->GetCRC();
        $toDisplay .= "<li><b>CRC</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";

        $get = $this->GetCRC_UNCORR();
        $toDisplay .= "<li><b>CRC UNCORR</b>: ".$get." - ".gettype($get)."(".strlen($get).")\n";

        $toDisplay .= "</ul>\n";

		$toDisplay .= "<h4>Trafic sur les Interfaces:</h4>\n";
		$toDisplay .= "<ul>\n";
		$get = $this->getStreamOnInterface("eth0");
        $toDisplay .= "<li><b>eth0</b>:<ul><li>RX: ".$get[0]."</li><li>TX: ".$get[1]."</li></ul></li>\n";

		$get = $this->getStreamOnInterface("eth1");
        $toDisplay .= "<li><b>eth1</b>:<ul><li>RX: ".$get[0]."</li><li>TX: ".$get[1]."</li></ul></li>\n";

		$get = $this->getStreamOnInterface("ppp0");
        $toDisplay .= "<li><b>ppp0</b>:<ul><li>RX: ".$get[0]."</li><li>TX: ".$get[1]."</li></ul></li>\n";

		$get = $this->getStreamOnInterface("usb0");
        $toDisplay .= "<li><b>eth0</b>:<ul><li>RX: ".$get[0]."</li><li>TX: ".$get[1]."</li></ul></li>\n";

		$toDisplay .= "</ul>\n";
        return $toDisplay;	
    }  		    
}

?>